[PATCH 2/5] Display ID_PATH instead of WWID for DASDs as well.

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



---
 iw/filter_gui.py |    7 ++++---
 1 files changed, 4 insertions(+), 3 deletions(-)

diff --git a/iw/filter_gui.py b/iw/filter_gui.py
index 5f3e3a6..3dda8f6 100644
--- a/iw/filter_gui.py
+++ b/iw/filter_gui.py
@@ -618,9 +618,10 @@ class FilterWindow(InstallWindow):
             if d["XXX_SIZE"] == 0:
                 continue
 
-            # This isn't so great, but for iSCSI devices the path contains a lot
-            # of useful identifiying info that should be displayed.
-            if udev_device_is_iscsi(d):
+            # This isn't so great, but iSCSi and DASD devices have an ID_PATH
+            # that contains a lot of useful identifying info, so that should be
+            # displayed instead of a blank WWID.
+            if udev_device_is_iscsi(d) or udev_device_is_dasd(d):
                 ident = udev_device_get_path(d)
             else:
                 ident = udev_device_get_wwid(d)
-- 
1.6.5.1

_______________________________________________
Anaconda-devel-list mailing list
Anaconda-devel-list@xxxxxxxxxx
https://www.redhat.com/mailman/listinfo/anaconda-devel-list

[Index of Archives]     [Kickstart]     [Fedora Users]     [Fedora Legacy List]     [Fedora Maintainers]     [Fedora Desktop]     [Fedora SELinux]     [Big List of Linux Books]     [Yosemite News]     [Yosemite Photos]     [KDE Users]     [Fedora Tools]
  Powered by Linux